# Gaussian Segmentation

This is a project that implements a method for gaussian segmentation based on [Hallac 2018](https://arxiv.org/abs/1610.07435).


## Context

This is part of the course work of Non-linear optimization in the PhD program of Electronics Engineering in Instituto Superior Tecnico.